<?php

namespace CountriesStates\CountriesState\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use CountriesStates\CountriesState\Models\Countries;

class CountriesAction
{
    /**
     * Perform the complete action.
     *
     * @param Countries $countries
     *
     * @return Countries
     */
    public function complete(Countries $countries)
    {
        try {
            $countries->status = 'complete';
            return $countries->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Countries $countries
     *
     * @return Countries
     */public function verify(Countries $countries)
    {
        try {
            $countries->status = 'verify';
            return $countries->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Countries $countries
     *
     * @return Countries
     */public function approve(Countries $countries)
    {
        try {
            $countries->status = 'approve';
            return $countries->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Countries $countries
     *
     * @return Countries
     */public function publish(Countries $countries)
    {
        try {
            $countries->status = 'publish';
            return $countries->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Countries $countries
     *
     * @return Countries
     */
    public function archive(Countries $countries)
    {
        try {
            $countries->status = 'archive';
            return $countries->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Countries $countries
     *
     * @return Countries
     */
    public function unpublish(Countries $countries)
    {
        try {
            $countries->status = 'unpublish';
            return $countries->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
