<?php

namespace CountriesStates\CountriesState\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use CountriesStates\CountriesState\Models\States;

class StatesAction
{
    /**
     * Perform the complete action.
     *
     * @param States $states
     *
     * @return States
     */
    public function complete(States $states)
    {
        try {
            $states->status = 'complete';
            return $states->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param States $states
     *
     * @return States
     */public function verify(States $states)
    {
        try {
            $states->status = 'verify';
            return $states->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param States $states
     *
     * @return States
     */public function approve(States $states)
    {
        try {
            $states->status = 'approve';
            return $states->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param States $states
     *
     * @return States
     */public function publish(States $states)
    {
        try {
            $states->status = 'publish';
            return $states->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param States $states
     *
     * @return States
     */
    public function archive(States $states)
    {
        try {
            $states->status = 'archive';
            return $states->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param States $states
     *
     * @return States
     */
    public function unpublish(States $states)
    {
        try {
            $states->status = 'unpublish';
            return $states->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
